<?php

namespace Ciext\Controller;

abstract class AbstractAdminController extends \MX_Controller
{

    public function __construct()
    {
        parent::__construct();
        if (empty($this->rt_user->id_user)){
            show_404();
        }
        
        $this->load->library('ciext/admin_lib');
    }

}
