<?php
    /**
    * @property CI_DB_query_builder $db
    * @property CI_DB_forge $dbforge
    * @property CI_Benchmark $benchmark
    * @property CI_Calendar $calendar
    * @property CI_Cart $cart
    * @property CI_Config $config
    * @property CI_Controller $controller
    * @property CI_Email $email
    * @property CI_Encrypt $encrypt
    * @property CI_Exceptions $exceptions
    * @property RT_Form_validation $form_validation
    * @property CI_Ftp $ftp
    * @property CI_Hooks $hooks
    * @property CI_Image_lib $image_lib
    * @property CI_Input $input
    * @property RT_Lang $language
    * @property RT_Loader $load
    * @property CI_Log $log
    * @property CI_Model $model
    * @property CI_Output $output
    * @property CI_Pagination $pagination
    * @property CI_Parser $parser
    * @property RT_Profiler $profiler
    * @property RT_Router $router
    * @property CI_Session $session
    * @property CI_Sha1 $sha1
    * @property CI_Table $table
    * @property CI_Trackback $trackback
    * @property CI_Typography $typography
    * @property CI_Unit_test $unit_test
    * @property CI_Upload $upload
    * @property RT_URI $uri
    * @property CI_User_agent $user_agent
    * @property CI_Validation $validation
    * @property CI_Xmlrpc $xmlrpc
    * @property CI_Xmlrpcs $xmlrpcs
    * @property CI_Zip $zip
    * @property Db_lang_lib $db_lang_lib
    * @property Gettext_language $gettext_language
    * @property Image $image
    * @property Image_change $image_change
    * @property Js_css $js_css
    */

    class CI_Controller {};

    /**
    * @property CI_DB_query_builder $db
    * @property CI_DB_forge $dbforge
    * @property CI_Config $config
    * @property RT_Loader $load
    * @property CI_Session $session
    */

    class CI_Model {};


?>