<?php

$lang['404_head'] = 'помилка 404';
$lang['404_body'] = '<p>
            Сторінка, не знайдена. Перейдіть, будь ласка,<br/>
            на <a href="/">Головну</a>, або перевірте правильність даних,<br/>
            введених в адресну строку.
        </p>';