<?php

return array(
    'system_configurator'         => array(
        'admin_email' => array(
            'label'           => 'Administrator`s email',
            'callback'        => 'input',
            'callbck_options' => array(),
        ),
        'email_from'  => array(
            'label'           => 'Email from',
            'callback'        => 'input',
            'callbck_options' => array(),
        ),
    ),
    'ciext_parser_alias_callback' => array(
        'safe_mailto'  => 'ciext/parser/parser_safe_mailto',
        'date'         => 'ciext/parser/parser_date',
        'configurator' => 'ciext/parser/parser_configurator',
        'add_js'       => 'ciext/parser/parser_add_js',
        'add_css'      => 'ciext/parser/parser_add_css',
        'page_url'     => 'ciext/parser/parser_page_url',
    )
);
