<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
        <title>{title}</title>
        {js_list}
        {css_list}
    </head>
    <body>
        <div class="fake-header"></div>
        <div class="container">
            <header>
                <a href="/" target="_blank"><div class="logo"></div></a>
            </header> 
        
            <div class="well install_nav">
                {step_nav}
            </div>
            <div class="well form-horizontal install_content">
                {content}
            </div>
        
            <footer>
                <p class="created">Created by <a href="http://www.r-team.com.ua">R-team</a></p>
            </footer>
        </div>
    </body>
</html>