<?php 

$lang['browser_no_suport_head'] = 'Ваша версия браузера устарела';
$lang['browser_no_suport'] = '<h6>Обновите, пожалуйста, Ваш браузер до последней версии:</h6>
        <ul>
            <li>— <a href="http://www.google.com/chrome/intl/en/landing_chrome.html" target="_blank">Google Chrome</a></li>
            <li>— <a href="http://www.mozilla.org/en-US/firefox/new/" target="_blank">Mozilla</a></li>
            <li>— <a href="http://windows.microsoft.com/en-US/internet-explorer/downloads/ie-9/worldwide-languages" target="_blank">Internet Explorer 9</a></li>
        </ul>';

        
