<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade ciext module to version 1.1.13
 *
 * @author Igor Ratsun
 */
class ciext_upgrade_1_1_12 extends Abstract_upgrade
{

    public function up()
    {
        return '1.1.13';
    }

    public function down()
    {
        return '1.1.12';
    }

}
