<?php
// Buttons
$lang['save_btn'] = 'Сохранить';
$lang['cancel_btn'] = 'Отменить';
$lang['delete_btn'] = 'Удалить';
$lang['change_btn'] = 'Редактировать';
$lang['add_to_panel_btn'] = 'Добавить на панель быстрого запуска';

// Pages
$lang['page_admin'] = 'Админ панель';

// Message
$lang['msg_head_error'] = 'ошибка';
$lang['msg_access_denied'] = 'У вас недостаточно прав! Ви можете:';
$lang['msg_back'] = 'Вернуться на предыдущую страницу';
$lang['msg_relogin'] = 'Авторизоваться снова';
$lang['no data found'] = 'Нет событий для отображения';
$lang['Warning! Project is in development mode'] = '<b>Внимание!</b> Проект в режиме "development".';

// Top menu items
$lang['top_menu_1'] = 'Обновления';
$lang['top_menu_2'] = 'Панель управления';
$lang['top_menu_3'] = 'Файл-менеджер';
$lang['top_menu_4'] = 'SEO-модуль';
$lang['top_menu_5'] = 'Панель разработчика';

// Menu
$lang['menu_back_text'] = '<span>«</span>Назад';
$lang['menu_next_text'] = 'Вперед';
$lang['menu_title'] = 'Меню';
$lang['home_btn'] = 'Домой';
$lang['site_btn'] = 'На сайт';
$lang['exit_btn'] = 'Выйти';

// menu blocks
$lang['block_up_text'] = 'свернуть';
$lang['block_down_text'] = 'развернуть';

// search menu
$lang['search_text'] = 'поиск ...';
$lang['search_title'] = 'Результаты поиска:';

$lang['active'] = 'Так';
$lang['no_active'] = 'Ні';