<?php

(defined('BASEPATH')) OR exit('No direct script access allowed');

class RT_Exceptions extends CI_Exceptions
{

    /**
     * 404 Error Handler
     *
     * @uses	CI_Exceptions::show_error()
     *
     * @param	string	$page		Page URI
     * @param 	bool	$log_error	Whether to log the error
     * @return	void
     */
    public function show_404($page = '', $log_error = TRUE)
    {
        if (empty($page)) {
            $page = get_instance()->config->base_url(get_instance()->uri->uri_string());
        }

        return parent::show_404($page, $log_error);
    }

}
